===================
Django Admin Colors
===================

|build| |coverage| |health|

.. |build| image:: https://circleci.com/gh/victorfsf/django-admin-colors/tree/master.svg?style=shield
    :target: https://circleci.com/gh/victorfsf/django-admin-colors
    :alt: Build Status

.. |coverage| image:: https://coveralls.io/repos/github/victorfsf/django-admin-colors/badge.svg?branch=master
    :target: https://coveralls.io/github/victorfsf/django-admin-colors?branch=master
    :alt: Coverage Status

.. |health| image:: https://landscape.io/github/victorfsf/django-admin-colors/master/landscape.svg?style=flat
    :target: https://landscape.io/github/victorfsf/django-admin-colors/master
    :alt: Code Health

Report issues `here <https://github.com/victorfsf/django-admin-colors/issues/new>`_.

Installation/Usage: https://github.com/victorfsf/django-admin-colors/blob/master/README.md
